**`PgUp`** and **`PgDn`** scrolls up and down, the `/ss` command decides how much

**`Up`** and **`Down`** goes through the history of text you've written

**`Tab`** completes a nickname after writing the first couple letters

**`CTRL-A`** switches to the previous channel

**`CTRL-X`** switches to the next channel

**`CTRL-E`** is the `/a` command, jumps to the oldest unread message in another channel, or alt-tabs between two channels otherwise

**`CTRL-L`** is the `/r` command, redraws the screen to fix corruption. Use this if things are glitchy after resizing the terminal

**`CTRL-N`** is the `/v` command, toggle visibility of names in messages

**`CTRL-K`** followed by a number `0-9` or letter `a-f` changes colour mid-message, see `/cmap`

**`CTRL-B`** enables bold/bright text

**`CTRL-O`** changes back to default colour
